@@ -1,21 +1,20 @@
 import subprocess
 
-from django.db import connections
 from django.conf import settings
 from django.core.management.color import no_style
+from django.db import connections
 
-from .utils import (
-    psql,
-    progress,
-    to_model,
-    get_all_models,
-    schema_file_path,
-    to_app_model_label,
-    migrations_file_path,
-    sort_model_strategies,
-    get_pg_connection_args,
-)
 from .strategies import Exportable
+from .utils import (
+    get_all_models,
+    migrations_file_path,
+    progress,
+    psql,
+    schema_file_path,
+    sort_model_strategies,
+    to_app_model_label,
+    to_model,
+)
 
 
 def validate_strategies(only=None):
@@ -57,7 +56,6 @@ def export_schema(django_dbname):
             db_conf["NAME"],
             "--schema-only",
             "--format=plain",
-            *get_pg_connection_args(db_conf),
         ]
 
         subprocess.run(export_command, stdout=f, check=True)
@@ -70,7 +68,6 @@ def export_schema(django_dbname):
             "--data-only",
             "--table=django_migrations",
             "--format=plain",
-            *get_pg_connection_args(db_conf),
         ]
 
         subprocess.run(export_command, stdout=f, check=True)
@@ -86,15 +83,32 @@ def export_data(django_dbname, only=None, no_update=False):
         model = to_model(app_model_label)
 
         if isinstance(strategy, Exportable):
-            print("Exporting {} ({})".format(app_model_label, strategy.name))
             strategy.export(django_dbname, model, no_update)
 
 
 def sync_schema(django_dbname):
     db_conf = settings.DATABASES[django_dbname]
     pg_dbname = db_conf["NAME"]
+    pg_user = db_conf.get("USER") if db_conf.get("USER") else "postgres"
 
     psql("DROP DATABASE IF EXISTS {}".format(pg_dbname), None, db_conf)
+    psql(
+        """
+        DO $do$
+            BEGIN
+                IF NOT EXISTS (
+                    SELECT FROM pg_catalog.pg_roles
+                    WHERE  rolname = '{owner}'
+                )
+                THEN
+                    CREATE ROLE {owner} SUPERUSER LOGIN;
+                END IF;
+            END
+        $do$
+        """.format(owner=pg_user),
+        None,
+        db_conf,
+    )
     psql(
         """
         CREATE DATABASE {database} WITH
@@ -104,7 +118,7 @@ def sync_schema(django_dbname):
             LC_CTYPE = 'en_GB.UTF-8'
             OWNER = {owner}
         """.format(
-            owner=db_conf.get("USER", "postgres"),
+            owner=pg_user,
             database=pg_dbname,
         ),
         None,
@@ -112,18 +126,16 @@ def sync_schema(django_dbname):
     )
 
     with schema_file_path().open() as f:
-        psql(f.read(), pg_dbname, db_conf)
+        psql(settings.DEVDATA_SQL_FILTER(f.read()), pg_dbname, db_conf)
 
     with migrations_file_path().open() as f:
-        psql(f.read(), pg_dbname, db_conf)
+        psql(settings.DEVDATA_SQL_FILTER(f.read()), pg_dbname, db_conf)
 
 
 def sync_data(django_dbname):
     model_strategies = sort_model_strategies(settings.DEVDATA_STRATEGIES)
-    for app_model_label, strategy in model_strategies:
+    for app_model_label, strategy in progress(model_strategies):
         model = to_model(app_model_label)
-
-        print("Syncing {} ({})".format(app_model_label, strategy.name))
         strategy.sync(django_dbname, model)
 
 
